#!/usr/bin/python
# matahari-gui.py - GUI for matahari
# Copyright (c) 2012 Red Hat, Inc.
# Authors: Roman Rakus <rrakus@redhat.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


from gi.repository import Gtk
import os
import qmf.console as qc

class MainWindow:
    """
    Main window
    """
    def __init__(self):
        builder = Gtk.Builder()
        if os.access("./matahari-gui.ui", os.F_OK):
            builder.add_from_file ("./matahari-gui.ui")
        else:
            builder.add_from_file (
                "/usr/share/matahari-gui/matahari-gui.ui")
        builder.connect_signals(self)

        self.main_window = builder.get_object("Main Window")
        self.entry_host = builder.get_object("entry_host")
        self.spinbutton_port = builder.get_object("spinbutton_port")
        self.label_broker = builder.get_object("label_broker")
        self.treestore_agents = builder.get_object("treestore_agents")
        self.treeview_agents = builder.get_object("treeview_agents")

        self._broker = None
        self._session = None

        self._agents = []

    def run(self):
        """
        start the main application
        """
        self.main_window.show_all()
        Gtk.main()

    def destroy(self, *args):
        """
        end
        """
        self._disconnect()
        Gtk.main_quit()

    def _disconnect(self):
        """Disconnect and close session"""
        if self._session:
            if self._broker:
                self._session.delBroker(self._broker)
            self._broker = None
            self._session.close()
            self._session = None

    def refill_treestore(self):
        self.treestore_agents.clear()
        treeiter_top = self.treeview_agents.get_model().get_iter_first()
        for agent in self._agents:
            print "AGENT: ", agent, type(agent)
            treeiter = self.treestore_agents.append(None,
                [str(agent).split(":")[2],
                agent.hostname,
                None, None, True, True, False])



    def _connect(self, host, port):
        """
        Connect to broker
        """
        addr = 'amqp://%(host)s:%(port)u' % {'host': host, 'port': port}
        self._session = qc.Session()
        self._broker = self._session.addBroker(addr)
        print self._broker
        self.label_broker.set_text("%(host)s:%(port)s" %{
                                   "host" : self._broker.host,
                                   "port" : str(self._broker.port)})
        self._agents = self._session.getObjects(_class="Agent",
                                                _package="org.matahariproject")
        self.refill_treestore()

    def connect_clicked(self, *args):
        """
        We want to connect to some broker
        """
        self._connect(
            self.entry_host.get_text(), int(self.spinbutton_port.get_text()))

    def toggled(self, renderer, index):
        """Toggled state of selection of one of agent"""
        self.toggle_selected(renderer, index)

    def toggle_selected(self, renderer, index):
        self.liststore_agents[index][0] = not self.liststore_agents[index][0]

if __name__ == "__main__":
    MW = MainWindow()
    MW.run()
